@@ -8,7 +8,7 @@
 #include <unistd.h>
 
 static gchar *get_theme_dir();
-static gboolean change_dir(const gchar *dir);
+/* static gboolean change_dir(const gchar *dir); */
 static gchar* name_from_dir(const gchar *dir);
 static gchar* install_theme_to(const gchar *file, const gchar *to);
 static gboolean create_theme_archive(const gchar *dir, const gchar *name,
@@ -142,6 +142,7 @@ static gchar* name_from_dir(const gchar *dir)
     return g_path_get_basename(dir);
 }
 
+/*
 static gboolean change_dir(const gchar *dir)
 {
     if (chdir(dir) == -1) {
@@ -152,6 +153,7 @@ static gboolean change_dir(const gchar *dir)
     }
     return TRUE;
 }
+*/
 
 static gchar* install_theme_to(const gchar *file, const gchar *to)
 {
