@@ -45,7 +45,7 @@
     <message>
         <location filename="../obconf.ui" line="46"/>
         <source>Move &amp; Resize</source>
-        <translation>Преместване и преорзмеряване</translation>
+        <translation>Преместване и преоразмеряване</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="51"/>
@@ -80,7 +80,7 @@
     <message>
         <location filename="../obconf.ui" line="108"/>
         <source>&amp;Windows retain a border when undecorated</source>
-        <translation>&amp;Недекорираните прозорци запазват границите</translation>
+        <translation>&amp;Недекорираните прозорци запазват рамките</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="115"/>
@@ -242,7 +242,7 @@ D: Показване във всички работни плотове</transla
     <message>
         <location filename="../obconf.ui" line="480"/>
         <source>Amount of resistance against screen &amp;edges:</source>
-        <translation>Съпротивление към границите на &amp;екрана:</translation>
+        <translation>Съпротивление към краищата на &amp;екрана:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="500"/>
@@ -348,7 +348,7 @@ D: Показване във всички работни плотове</transla
     <message>
         <location filename="../obconf.ui" line="710"/>
         <source>&amp;Delay before focusing and raising windows:</source>
-        <translation>&amp;Забавяне преди фокусиране и преорзмеряване на прозорци:</translation>
+        <translation>&amp;Забавяне преди фокусиране и преоразмеряване на прозорци:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="730"/>
@@ -476,7 +476,7 @@ D: Показване във всички работни плотове</transla
     <message>
         <location filename="../obconf.ui" line="1065"/>
         <source>Top Right</source>
-        <translation>Оторе вдясно</translation>
+        <translation>Отгоре вдясно</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1070"/>
@@ -587,19 +587,19 @@ D: Показване във всички работни плотове</transla
 <context>
     <name>Obconf::MainDialog</name>
     <message>
-        <location filename="../theme.cpp" line="149"/>
+        <location filename="../theme.cpp" line="152"/>
         <source>Choose an Openbox theme</source>
         <translation>Избиране на тема на Openbox</translation>
     </message>
     <message>
-        <location filename="../desktops.cpp" line="65"/>
-        <location filename="../desktops.cpp" line="87"/>
-        <location filename="../desktops.cpp" line="99"/>
+        <location filename="../desktops.cpp" line="67"/>
+        <location filename="../desktops.cpp" line="89"/>
+        <location filename="../desktops.cpp" line="101"/>
         <source>(Unnamed desktop)</source>
         <translation>(Работен плот без име)</translation>
     </message>
     <message>
-        <location filename="../mouse.cpp" line="57"/>
+        <location filename="../mouse.cpp" line="56"/>
         <source>Custom actions</source>
         <translation>Потребителски действия</translation>
     </message>
@@ -657,7 +657,7 @@ The following errors were reported:
     </message>
     <message>
         <location filename="../archive.cpp" line="95"/>
-        <location filename="../archive.cpp" line="178"/>
+        <location filename="../archive.cpp" line="180"/>
         <source>Unable to run the &quot;tar&quot; command: %1</source>
         <translation>Невъзможно изпълнение на &quot;tar&quot; командата: %1</translation>
     </message>
@@ -672,12 +672,7 @@ The following errors were reported:
         <translation>&quot;%1&quot; не е валидна директория на теми на Openbox</translation>
     </message>
     <message>
-        <location filename="../archive.cpp" line="148"/>
-        <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Не може да се премести директория &quot;%1&quot;: %2</translation>
-    </message>
-    <message>
-        <location filename="../archive.cpp" line="185"/>
+        <location filename="../archive.cpp" line="187"/>
         <source>Unable to extract the file &quot;%1&quot;.
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
@@ -711,7 +706,7 @@ Copyright (c) 2013        Hong Jen Yee (PCMan)
 
 Тази програма идва без абсолютно никаква гаранция.
 Това е безплатен софтуер и вие сте добре дошли да го разпространявате
-при определени условия. Вижте файла COPYING за подробности.n
+при определени условия. Вижте файла COPYING за подробности.
 
 </translation>
     </message>
@@ -726,7 +721,7 @@ Options:
   --archive THEME       Create a theme archive from the given theme directory
   --config-file FILE    Specify the path to the config file to use
 </source>
-        <translation>Синтакс: obconf [options] [ARCHIVE.obt]
+        <translation>Синтаксис: obconf [options] [ARCHIVE.obt]
 
 Опции:
   --help                Показване на тази помощ
@@ -758,22 +753,34 @@ Options:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="223"/>
-        <location filename="../obconf-qt.cpp" line="238"/>
+        <location filename="../obconf-qt.cpp" line="206"/>
+        <source>Platform Unsupported</source>
+        <translation>Неподдържана платформа</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="207"/>
+        <source>ObConf-Qt is unsupported under Wayland.
+</source>
+        <translation>ObConf-Qt не се поддържа под Wayland.
+</translation>
+    </message>
+    <message>
+        <location filename="../obconf-qt.cpp" line="241"/>
+        <location filename="../obconf-qt.cpp" line="256"/>
         <source>Error</source>
         <translation>Грешка</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="224"/>
+        <location filename="../obconf-qt.cpp" line="242"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Неуспешно зареждане на rc.xml. Вероятно не сте успели да инсталирате Openbox правилно.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="236"/>
+        <location filename="../obconf-qt.cpp" line="254"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
-        <translation>Грехка при анализ на конфигурационния файл на Openbox. Файлът не е валиден XML.
+        <translation>Грешка при анализ на конфигурационния файл на Openbox. Файлът не е валиден XML.
 
 Съобщение: %1</translation>
     </message>
