@@ -388,7 +388,7 @@ D: Zobrazovat na všech monitorech</translation>
     <message>
         <location filename="../obconf.ui" line="786"/>
         <source>Double click ti&amp;me:</source>
-        <translation>Doba &amp;trvání pro dvojklik:</translation>
+        <translation>Doba &amp;trvání pro dvojkliku:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="826"/>
@@ -511,7 +511,7 @@ D: Zobrazovat na všech monitorech</translation>
     <message>
         <location filename="../obconf.ui" line="1109"/>
         <source>&amp;Floating position:</source>
-        <translation>&amp;Plovoucí pozice:</translation>
+        <translation>&amp;Plovoucí umístění:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1134"/>
@@ -756,13 +756,14 @@ Volby:
     <message>
         <location filename="../obconf-qt.cpp" line="206"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Nepodporovaná platforma</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="207"/>
         <source>ObConf-Qt is unsupported under Wayland.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>ObConf-Qt není pod Waylandem podporován.
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="241"/>
