@@ -755,13 +755,14 @@ Opciók:
     <message>
         <location filename="../obconf-qt.cpp" line="206"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Nem támogatott platform</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="207"/>
         <source>ObConf-Qt is unsupported under Wayland.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Az ObConf-Qt nem támogatott Waylandon
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="241"/>
