@@ -672,7 +672,7 @@ The following errors were reported:
     <message>
         <location filename="../archive.cpp" line="138"/>
         <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
-        <translation>&quot;%1&quot;은(는) 올바른 Openbox 테마 디렉토리가 아닌 것 같습니다</translation>
+        <translation>&quot;%1&quot;은(는) 올바른 Openbox 테마 디렉터리가 아닌 것 같습니다</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="187"/>
