@@ -754,13 +754,14 @@ voľby:
     <message>
         <location filename="../obconf-qt.cpp" line="206"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>Nepodporovaná platforma</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="207"/>
         <source>ObConf-Qt is unsupported under Wayland.
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Systém Wayland nepodporuje ObConf-Qt.
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="241"/>
