@@ -732,7 +732,7 @@ Flaggor:
     <message>
         <location filename="../obconf-qt.cpp" line="206"/>
         <source>Platform Unsupported</source>
-        <translation>Plattform stöds ej</translation>
+        <translation>Plattformen saknar stöd</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="207"/>
